@@ -11,7 +11,7 @@ use Business::OnlinePayment::HTTPS;
 
 @ISA = qw(Business::OnlinePayment::HTTPS);
 $DEBUG = 0;
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 # mapping out all possible endpoints
 # but this version will only be building out "charge", "void", & "credit"
@@ -238,7 +238,7 @@ sub submit {
     my @required_fields = qw/ Amount /;
     if ($action eq 'charge') {
         push @required_fields, $_
-          foreach (qw/ AccountNumber Cvv ExpirationMonth ExpirationYear /);
+          foreach (qw/ AccountNumber ExpirationMonth ExpirationYear /);
     }elsif ($action eq 'void') {
         push @required_fields, $_
           foreach (qw/ ReferenceNumber /);
